// pages/userCenter.js
const app = getApp()
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')
const envInfo = require('../../config/index').envInfo
let renderPage = null // 渲染页面数据对象(安全渲染)
let handlerDataOnPage = null
let config = require('../../configScreen/configScreen');

const logger = utils.logger

wxService.page({
  /**
   * 页面的初始数据
   */
  data: {
    pages:[],
    render: null, // 渲染页面数据对象(安全渲染)
    renderPageOver: false, // 渲染页面结束
    startX: 0,
    startY: 0,
    integralNum: 0,
    couponNum: 0,
    // isAllScreen: fullSucreen.isAllScreen
    isAllScreen: config.isAllScreen,
    token:'',
    isAuthorization: false
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.setData(
      {
        pages: [],
        groupLoadState: 'complete', // 活动分组加载标志
        homeApiLoading: true,
        render: null, // 渲染页面数据对象(安全渲染)
        isLastPage: false, // 页面段落加载完成
        renderPageOver: false, // 渲染页面结束
        // isAuthorization: true
      },
      () => {
        // this.loadMore()
      }
    )
    handlerDataOnPage = new utils.HandlerDataOnPage()
    renderPage = require('../../utils/renderPage').getRenderPage()
    handlerDataOnPage.init(this, 'pages')
    this.initPage()
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    this.setData({
      token: wx.getStorageSync('token')
    })
    if (wx.getStorageSync('_baseUserInfo')){
      // 积分数量
      this.getMemberPointInfo()
      // 优惠券数量
      this.getMemberCouponInfo()
    }
  },
  // 查询积分信息
  getMemberPointInfo(){
    wx.showLoading({
      title: '加载中'
    })
    wxService.get(`/member/memberPoint/getMyPointInfo`).then(res => {
      if(res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          this.setData({
            integralNum: data && data.point || 0
          })
        }
      } 
    })
  },
// 查询优惠券数量
  getMemberCouponInfo(){
    wx.showLoading({
      title: '加载中'
    })
    wxService.post(`/coupon/coupon/memberCouponCount`).then(res => {
      const { result, data } = res && res.data && res.data.result
      if (result == 0) {
        wx.hideLoading()
        this.setData({
          couponNum: data && data[1] || 0
        })
      }
    })
  },
  touchStart(e) {
    this.setData({
      startX: e.changedTouches[0].clientX,
      startY: e.changedTouches[0].clientY
    });
  },
  touchEnd(e) {
    let x = e.changedTouches[0].clientX;
    let y = e.changedTouches[0].clientY;
    // endX, endY, startX, startY
    const {startX, startY} = this.data
    let isTouchLeft  = utils.getTouchData(x, y, startX, startY)
    // 触发左划事件
    if(isTouchLeft == 'left') {
      const {appid, path} = e.currentTarget.dataset
			// 获取当前帐号信息
			const accountInfo = utils.getAccountInfo()
			// 是当前小程序 直接跳转
      if (wx.getStorageSync('_baseUserInfo')){
        if(accountInfo.miniProgram.appId == appid){
          wxService.router(`${path}`)
        } else {
          // 	跳转其他小程序
          wx.navigateToMiniProgram({
            appId: appid,
            path: `${path}`,
            success: e => {
              console.log(e)
            },
            fail: e => {
              console.log(e)
            },
            complete: e => {
              console.log(e)
            },
          })
        }
      }else{
        this.setData({
          isAuthorization: true
        })
      }
    }
  },
  // page 信息
  initPage(){
    this.setData({
      products: []
    })
    wx.showLoading({
      title: '加载中'
    })
    wxService.post(`/merchant/modelPage/getDetailById?pageId=3&brandId=${app.globalData.brandId}`).then(res => {
      const {result,data} = res.data
      if(result == 0){
        // 动态设置title
        wx.setNavigationBarTitle({
          title: data.page.title
        })
        // 段落
        const products = data.paragraphs
        const filterResult = products.map((res,index)=>{
          return {
            ...res,index
          }
        }).filter(item=> {
          // wx.hideLoading()
        })

        const render = renderPage.initPaging(filterResult).initRenderData(products)
        this.data.render = render
        const renderData = render.next()
        this.data.renderPageOver = renderData.done
        this.renderPageFunc({ products: renderData.value })
      }

    }).finally(() => {
      wx.hideLoading();
    })
  },
  /**
	 * 渲染数据(合并之前的数据)
	 * @param products 数组数据
	 * @param isLastPage
	 * @param now
	 */
  renderPageFunc ({ products }) {
    let productData = handlerDataOnPage.handlerArray(products)
    logger.log('productData.keysNum', productData.keysNum(), productData)
    
      this.setData({
        ...productData
      },()=>{
        wx.hideLoading()
      })
 
  }
})